from nltk.stem import WordNetLemmatizer

class SceneNameFilter(object):
    '''
    Gets a name of a scene in the form A_NAME, where A is a prefix and NAME is the name of a scene
    with underlines as whitespaces (i. e. b_book_store). An object of this class extracts the scene
    name without the prefix and replaces underlines with whitespaces.
    '''
    
    @staticmethod
    def remove_attributes(scene_name):
        '''
        @param scene_name: A string of the form A_NAME, where A is a prefix and NAME is the name of
        a scene with underlines as whitespaces (i. e. b_book_store).
        @return: the given string without indoor/outdoor attributes
        '''
        return scene_name.replace("_indoor", "").replace("_outdoor", "")

    @staticmethod
    def filter(scene_name):
        '''
        @param scene_name: A string of the form A_NAME, where A is a prefix and NAME is the name of
        a scene with underlines as whitespaces (i. e. b_book_store).
        @return: the given string without the prefix and underlines replaced with whitespaces.
        '''
        
        result = ""
        splitted_scene_name = scene_name.split("_")
        i = 1
        
        while i < len(splitted_scene_name):
            result += splitted_scene_name[i] + " "
            i += 1
        
        return result.strip()
    
    
class ObjectNameFilter(object):
    
    # Initialize static word net lemmatizer
    wln = WordNetLemmatizer()
       
    @staticmethod
    def filter(object_name):
        '''
        @param object_name: A string of an object name as given in the SUN annotations 
        @return: A filtered and stemmed name - removing attributes as standing, walking, sitting, occluded, part
        '''
        # Filter occlusion tags
        filtered_obj_name = object_name.replace(" occluded", "")
        filtered_obj_name = filtered_obj_name.replace(" crop", "")
        filtered_obj_name = filtered_obj_name.replace(" part", "")
        # Filter attributes like standing, walking, sitting, in blue jacket and so on
        if "person" in filtered_obj_name:
            filtered_obj_name = "person"
        filtered_obj_name = filtered_obj_name.strip()
        filtered_obj_name = ObjectNameFilter.stem(filtered_obj_name)
        return filtered_obj_name
    
    @staticmethod
    def stem(object_name):
        '''
        @param object_name: A string of an object name
        @return: A stemmed name - using the WordNet's morphology function.
        Returns the input word unchanged if it cannot be found in WordNet
        '''
        return ObjectNameFilter.wln.lemmatize(object_name)